#!/usr/bin/env python
"""
elastic2ieee.py

Convert elastic tensor from ELASTIC_TENSOR file to IEEE format using structure from POSCAR.

Usage: 
    Put this script in the directory containing POSCAR and ELASTIC_TENSOR files
    Run: python elastic2ieee.py
"""

#基于atomate2的方法：
#werner@x13dai-t:~/Public/repo/github.com/materialsproject/atomate2.git$ find . -type f -name test_elastic.py |grep vasp
#./tests/vasp/flows/test_elastic.py

#寻找 convert_to_ieee 的使用方法，进而写出此脚本：
#werner@x13dai-t:~/Public/repo/github.com/materialsproject/atomate2.git$ cd "/home/werner/Public/repo/github.com/materialsproject/pymatgen.git" && ug -A10 -B10 'convert_to_ieee' -g '*.py'


from pymatgen.core.structure import Structure
from pymatgen.core.tensors import Tensor
import numpy as np

# 设置numpy打印选项
np.set_printoptions(suppress=True, precision=4, floatmode='fixed')

# 从POSCAR读取结构
structure = Structure.from_file("POSCAR")

# 从ELASTIC_TENSOR读取弹性张量
elastic_data = []
with open("ELASTIC_TENSOR", 'r') as f:
    next(f)  # 跳过第一行
    for line in f:
        data = [float(x) for x in line.split()]
        if len(data) == 6:  # 确保是有效的数据行
            elastic_data.append(data)

elastic_tensor = np.array(elastic_data)

# 转换为Tensor对象并转换到IEEE格式
tensor = Tensor.from_voigt(elastic_tensor)
ieee_tensor = tensor.convert_to_ieee(structure)

print("\nOriginal Elastic Tensor (Voigt notation, GPa):")
print(elastic_tensor)
print("\nIEEE Standard Elastic Tensor (Voigt notation, GPa):")
print(ieee_tensor.voigt)

# 打印主要弹性常数变化
def print_constants(tensor, name=""):
    c11 = tensor[0,0]
    c12 = tensor[0,1]
    c44 = tensor[3,3]
    print(f"\n{name} elastic constants (GPa):")
    print(f"C11: {c11:.4f}")
    print(f"C12: {c12:.4f}")
    print(f"C44: {c44:.4f}")

print_constants(elastic_tensor, "Original")
print_constants(ieee_tensor.voigt, "IEEE")
