#!/usr/bin/env python

"""
Convert any input structure to conventional cell and output as POSCAR format.
The input can be any structure format that pymatgen supports (cif, POSCAR, etc.).

Usage:
    python struct2conv.py -i input_structure              # use default output name (POSCAR_conventional)
    python struct2conv.py -i input_structure -o POSCAR    # specify output name
"""

from pymatgen.core import Structure
from pymatgen.io.vasp import Poscar
from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
import argparse

def convert_structure(input_file, output_file="POSCAR_conventional"):
    """
    将任意输入结构转换为常规胞的POSCAR格式
    
    Args:
        input_file (str): 输入文件路径（支持cif、POSCAR等pymatgen可读取的格式）
        output_file (str): 输出的POSCAR文件路径
    """
    # 读取结构文件
    structure = Structure.from_file(input_file)
    
    # 创建SpacegroupAnalyzer对象
    analyzer = SpacegroupAnalyzer(structure)
    
    # 获取常规标准结构
    conventional_structure = analyzer.get_conventional_standard_structure()
    
    # 创建POSCAR对象并写入文件
    poscar = Poscar(conventional_structure)
    poscar.write_file(output_file)
    
    # 打印结构信息
    print(f"\nInput file: {input_file}")
    print(f"Output file: {output_file}")
    print("\nSpace group information:")
    print(f"Space group symbol: {analyzer.get_space_group_symbol()}")
    print(f"Space group number: {analyzer.get_space_group_number()}")
    print(f"Crystal system: {analyzer.get_crystal_system()}")

if __name__ == "__main__":
    # 创建参数解析器
    parser = argparse.ArgumentParser(
        description='Convert any structure to conventional cell POSCAR'
    )
    parser.add_argument('-i', '--input', required=True,
                      help='Input structure file (supports multiple formats: cif, POSCAR, etc.)')
    parser.add_argument('-o', '--output', default='POSCAR_conventional',
                      help='Output POSCAR file name (default: POSCAR_conventional)')
    
    # 解析命令行参数
    args = parser.parse_args()
    
    # 执行转换
    convert_structure(args.input, args.output)

